CommandPalette

Struct CommandPalette 

pub struct CommandPalette { /* private fields */ }
TextView that used to display extra information

Currently, we will use command palette to display extra information like full cgroup name. But the idea for this view is something like vim’s command palette that use for input operation command like search, filter, rearrange, apply config, etc.

Implementations

Source

impl CommandPalette

pub fn new<V: 'static + ViewBridge>( name: &'static str, content: &str, cmd_controllers: Rc<RefCell<HashMap<&'static str, Controllers>>>, ) -> Self

Create a new CommandPalette

pub fn run_cmd<V: 'static + ViewBridge>( name: &'static str, c: &mut Cursive, cmd: &str, )

Run the captured command

pub fn reset_cmd(&mut self)

pub fn invoke_cmd(&mut self)

Turn cmd_palette into command input mode

pub fn is_cmd_mode(&self) -> bool

Check if command palette is in command mode

pub fn set_info<T: Into<String>>(&mut self, content: T)

Set the display info

pub fn set_alert<T: Into<String>>(&mut self, content: T)

Set alert This will preempt the command palette mode.

pub fn set_filter(&mut self, filter_info: Option<(String, String)>)

pub fn toggle_fold(&mut self)

pub fn is_alerting(&self) -> bool

pub fn get_content(&self) -> &str