Module stats_view

Module stats_view 

Structs

ColumnTitles
StatsView
StatsView is a view wrapper that wraps tabs, titles, and list of stats.

Traits

StateCommon
A trait that defines common state data querying or event handling.
ViewBridge
ViewBridge defines how a ConcreteView will relate to StatsView