pub struct StatsView<V: 'static + ViewBridge> {
pub state: Rc<RefCell<V::StateType>>,
pub reverse_sort: bool,
pub event_controllers: Rc<RefCell<HashMap<Event, Controllers>>>,
/* private fields */
}Expand description
StatsView is a view wrapper that wraps tabs, titles, and list of stats.
Terminology:
title: A title here means a column name in the stats table. We call it title to align with
below_derive’s function get_title_line.
tab or topic: A tab or topic is the content of “Tabs” defined in the module level description.
For example, “general”, “cpu”, “pressure”, etc.
The tab_titles_map defines a hashmap between a tab name and a vector of its corresponding
string titles. This will help StatsView to switch stats headline(columns name) when a user switching
tabs. This hashmap will be automatically generated by tab_view_map.
tab_view_map defines a map relationship between a tab name and its concrete V
data structure. The V here represents “view” which, in implementation, is a enum of
“tab” data structure. And each “tab” defines stats data and will derive the BelowDecor
to generate all display functions. Please check the implementation of V for more details.
detailed_view here is our cursive object. I wrapped it with OnEventView in order to
let the concrete “view“s to define their customized handler. You can think the detailed_view
will be something like this
OnEventView –> Panel –> LinearLayout::Vertical –> Child 0: A TabView that represent the topic tab –> child 1: ScrollView –> LinearLayout::Vertical –> child 0: A TabView that represent the title header tab –> child 1: A SelectView that represents the detail stats –> child 2: Command palette
state defines the state of a view. Filters, sorting orders will be defined here.
Fields
state: Rc<RefCell<V::StateType>>reverse_sort: boolevent_controllers: Rc<RefCell<HashMap<Event, Controllers>>>Implementations
Sourceimpl<V: 'static + ViewBridge> StatsView<V>
impl<V: 'static + ViewBridge> StatsView<V>
pub fn new( name: &'static str, tabs: Vec<String>, tab_view_map: HashMap<String, V>, select_view: SelectView<<V::StateType as StateCommon>::KeyType>, state: V::StateType, event_controllers: Rc<RefCell<HashMap<Event, Controllers>>>, cmd_controllers: Rc<RefCell<HashMap<&'static str, Controllers>>>, ) -> Self
pub fn update_title(&mut self)
pub fn on_event<F, E>(self, trigger: E, cb: F) -> Self
pub fn get_tab_view(&mut self) -> ViewRef<TabView>
pub fn get_title_view(&mut self) -> ViewRef<TabView>
pub fn get_list_scroll_view( &mut self, ) -> &mut ScrollView<NamedView<SelectView<<V::StateType as StateCommon>::KeyType>>>
pub fn get_detail_view( &mut self, ) -> ViewRef<SelectView<<V::StateType as StateCommon>::KeyType>>
pub fn get_cmd_palette(&mut self) -> ViewRef<CommandPalette>
pub fn get_screen_width(&mut self) -> usize
pub fn set_horizontal_offset(&mut self, x: usize)
pub fn refresh(&mut self, c: &mut Cursive)
pub fn feed_data(self, c: &mut Cursive) -> Self
pub fn refresh_myself(c: &mut Cursive)
pub fn set_alert(&mut self, msg: &str)