pub struct CommandPalette { /* private fields */ }Expand description
TextView that used to display extra information
Currently, we will use command palette to display extra information like full cgroup name. But the idea for this view is something like vim’s command palette that use for input operation command like search, filter, rearrange, apply config, etc.
Implementations
Sourceimpl CommandPalette
impl CommandPalette
Sourcepub fn new<V: 'static + ViewBridge>(
name: &'static str,
content: &str,
cmd_controllers: Rc<RefCell<HashMap<&'static str, Controllers>>>,
) -> Self
pub fn new<V: 'static + ViewBridge>( name: &'static str, content: &str, cmd_controllers: Rc<RefCell<HashMap<&'static str, Controllers>>>, ) -> Self
Create a new CommandPalette
Sourcepub fn run_cmd<V: 'static + ViewBridge>(
name: &'static str,
c: &mut Cursive,
cmd: &str,
)
pub fn run_cmd<V: 'static + ViewBridge>( name: &'static str, c: &mut Cursive, cmd: &str, )
Run the captured command
pub fn reset_cmd(&mut self)
Sourcepub fn invoke_cmd(&mut self)
pub fn invoke_cmd(&mut self)
Turn cmd_palette into command input mode
Sourcepub fn is_cmd_mode(&self) -> bool
pub fn is_cmd_mode(&self) -> bool
Check if command palette is in command mode
Sourcepub fn set_alert<T: Into<String>>(&mut self, content: T)
pub fn set_alert<T: Into<String>>(&mut self, content: T)
Set alert This will preempt the command palette mode.
pub fn set_filter(&mut self, filter_info: Option<(String, String)>)
pub fn toggle_fold(&mut self)
pub fn is_alerting(&self) -> bool
pub fn get_content(&self) -> &str